@@ -1,7 +1,7 @@
 package Sidef {
 
     use 5.014;
-    our $VERSION = 0.0900002;
+    our $VERSION = '0.10';
 
     our $SPACES      = 0;    # the current number of spaces
     our $SPACES_INCR = 4;    # the number of spaces incrementor
@@ -108,7 +108,7 @@ package Sidef {
     my ($self, @args) = @_;
 
     $self = ref($self) if ref($self);
-    $self =~ /^Sidef::/ or return;
+    index($self, 'Sidef::') == 0 or return;
     eval { require $self =~ s{::}{/}rg . '.pm' };
 
     if ($@) {
