@@ -51,6 +51,7 @@ package Sidef::Deparse::Perl {
         $opts{before} .= <<'HEADER';
 
 use utf8;
+use 5.014;
 use Sidef;
 use Sidef::Types::Number::Number;
 use Sidef::Types::Number::NumberFast;
@@ -59,9 +60,6 @@ binmode(STDIN,  ":utf8");
 binmode(STDOUT, ":utf8");
 binmode(STDERR, ":utf8") if $^P == 0;    # to work under Devel::* modules
 
-use 5.014;
-no if $] >= 5.018, warnings => 'experimental::lexical_topic';
-
 my $ARGV = Sidef::Types::Array::Array->new(map {Sidef::Types::String::String->new($_)} @ARGV);
 
 package Sidef::Variable::PerlVar {
@@ -169,7 +167,9 @@ HEADER
 
     sub _dump_var {
         my ($self, $var) = @_;
-        exists($var->{array}) ? '@' : exists($var->{hash}) ? '%' : '$' . $var->{name};
+            exists($var->{array}) ? '@'
+          : exists($var->{hash})  ? '%'
+          : '$' . ($var->{name} =~ /^_+\z/ ? ('_' . $var->{name}) : $var->{name});
     }
 
     sub _dump_vars {
@@ -216,7 +216,7 @@ HEADER
         }
         elsif ($ref eq 'Sidef::Variable::Variable') {
             if ($obj->{type} eq 'var' or $obj->{type} eq 'static' or $obj->{type} eq 'const') {
-                $code = '$' . $obj->{name};
+                $code = $self->_dump_var($obj);
             }
             elsif ($obj->{type} eq 'func' or $obj->{type} eq 'method') {
                 if ($addr{$refaddr}++) {
@@ -225,9 +225,22 @@ HEADER
                 }
                 else {
                     my $block = $obj->{value};
-                    $code = "sub $obj->{name}" if $obj->{name} ne '';
-                    local $self->{function} = refaddr($block) if $obj->{name} ne '';
-                    $code .= $self->deparse_expr({self => $block});
+
+                    # Alphanumeric name
+                    if ($obj->{name} =~ /^[_\pL][_\pL\pN]*\z/) {
+                        $code = "sub $obj->{name}" if $obj->{name} ne '';
+                        local $self->{function} = refaddr($block) if $obj->{name} ne '';
+                        $code .= $self->deparse_expr({self => $block});
+                    }
+
+                    # Non-alphanumeric name
+                    else {
+                        $code =
+                          "{ no strict 'refs'; *{__PACKAGE__ . '::' . " . q{"} . quotemeta($obj->{name}) . q{"} . "} = sub ";
+                        local $self->{function} = refaddr($block) if $obj->{name} ne '';
+                        $code .= $self->deparse_expr({self => $block});
+                        $code .= '}';
+                    }
                 }
             }
         }
@@ -245,10 +258,10 @@ HEADER
             }
         }
         elsif ($ref eq 'Sidef::Variable::InitLocal') {
-            $code = "my $obj->{name}";
+            $code = 'my ' . $self->_dump_var($obj);
         }
         elsif ($ref eq 'Sidef::Variable::Local') {
-            $code = "$obj->{name}";
+            $code = $self->_dump_var($obj);
         }
         elsif ($ref eq 'Sidef::Object::Unary') {
             $code = qq{'$ref'};
@@ -306,7 +319,7 @@ HEADER
 
                             $code .= "\n";
                             $code .= " " x $Sidef::SPACES;
-                            $code .= 'sub init {';
+                            $code .= 'sub new {';
                             $code .= "\n";
 
                             $Sidef::SPACES += $Sidef::SPACES_INCR;
@@ -369,8 +382,8 @@ HEADER
                         }
 
                         if (not $is_class) {
-                            if ($#vars == 0 and $vars[0]{name} eq '_') {
-                                $code .= ' ' x $Sidef::SPACES . "\$_ = Sidef::Types::Array::Array->new(\@_) if \@_;\n";
+                            if ($#vars == 0 and $vars[0]{name} =~ /^_+\z/) {
+                                $code .= ' ' x $Sidef::SPACES . "\$_" . $vars[0]{name} . " = \$_[0] if exists \$_[0];\n";
                             }
                             else {
                                 foreach my $i (0 .. $#{vars}) {
@@ -406,7 +419,7 @@ HEADER
             $code = $ref . '->new';
         }
         elsif ($ref eq 'Sidef::Sys::Sys') {
-            $code = exists($obj->{file_name}) ? '' : $self->make_constant($ref, 'Sys');
+            $code = $self->make_constant($ref, 'Sys');
         }
         elsif ($ref eq 'Sidef::Parser') {
             $code = $ref . '->new';
@@ -450,19 +463,22 @@ HEADER
         }
         elsif ($ref eq 'Sidef::Types::Glob::FileHandle') {
             if ($obj->{fh} eq \*STDIN) {
-                $code = $ref . '->new(fh => \*STDIN)';
+                $code = $self->make_constant($ref, 'STDIN', 'fh => \*STDIN');
             }
             elsif ($obj->{fh} eq \*STDOUT) {
-                $code = $ref . '->new(fh => \*STDOUT)';
+                $code = $self->make_constant($ref, 'STDOUT', 'fh => \*STDOUT');
             }
             elsif ($obj->{fh} eq \*STDERR) {
-                $code = $ref . '->new(fh => \*STDERR)';
+                $code = $self->make_constant($ref, 'STDERR', 'fh => \*STDERR');
             }
             elsif ($obj->{fh} eq \*ARGV) {
-                $code = $ref . '->new(fh => \*ARGV)';
+                $code = $self->make_constant($ref, 'ARGF', 'fh => \*ARGV');
             }
             else {
-                $code = $ref . '->new(fh => \*DATA)';
+                my $data = quotemeta(
+                                     do { seek($obj->{fh}, 0, 0); local $/; readline($obj->{fh}) }
+                                    );
+                $code = $self->make_constant($ref, 'DATA', qq{fh => do {open my \$fh, '<', \\"$data"; \$fh}});
             }
         }
         elsif ($ref eq 'Sidef::Variable::Magic') {
