@@ -180,10 +180,10 @@ package Sidef::Deparse::Sidef {
         }
         elsif ($ref eq 'Sidef::Types::Block::Code') {
             if ($addr{refaddr($obj)}++) {
-                $code = %{$obj} ? '__BLOCK__' : 'Block';
+                $code = keys(%{$obj}) ? '__BLOCK__' : 'Block';
             }
             else {
-                if (%{$obj}) {
+                if (keys(%{$obj})) {
                     $code = '{';
                     if (exists($obj->{init_vars}) and @{$obj->{init_vars}} > 1) {
                         my $vars = $obj->{init_vars};
@@ -321,7 +321,7 @@ package Sidef::Deparse::Sidef {
             }
         }
         elsif ($ref eq 'Sidef::Types::Hash::Hash') {
-            $code = 'Hash';
+            $code = keys(%{$obj->{data}}) ? $obj->dump->get_value : 'Hash';
         }
         elsif ($ref eq 'Sidef::Types::Glob::Socket') {
             $code = 'Socket';
@@ -424,6 +424,18 @@ package Sidef::Deparse::Sidef {
             foreach my $call (@{$expr->{call}}) {
                 my $method = $call->{method};
 
+                if (ref($method) ne '') {
+                    $method = (
+                               '('
+                                 . $self->deparse_expr(
+                                                       ref($method) eq 'HASH'
+                                                       ? $method
+                                                       : {self => $method}
+                                                      )
+                                 . ')'
+                              );
+                }
+
                 if ($code eq 'Hash' and $method eq ':') {
                     $method = 'new';
                 }
@@ -434,10 +446,7 @@ package Sidef::Deparse::Sidef {
                     $code = '(' . $code . ')';
                 }
 
-                if (ref($method) eq 'HASH') {
-                    $code .= '.(' . $self->deparse_expr($method) . ')';
-                }
-                elsif ($method =~ /^[[:alpha:]_]/) {
+                if ($method =~ /^[[:alpha:]_(]/) {
                     $code .= '.' if $code ne '';
                     $code .= $method;
                 }
