@@ -27,7 +27,7 @@ package Sidef::Module::OO {
                    local $Sidef::Types::Number::Number::GET_PERL_VALUE = 1;
                        ref($_) eq __PACKAGE__            ? $_->{module}
                      : ref($_) eq 'Sidef::Variable::Ref' ? $_->get_var->get_value
-                     : ref($_) =~ /^Sidef::/             ? $_->get_value
+                     : index(ref($_), 'Sidef::') == 0 ? $_->get_value
                      : $_
                  } @arg
               )
@@ -43,12 +43,7 @@ package Sidef::Module::OO {
             return Sidef::Types::Array::List->new(map { Sidef::Perl::Perl->to_sidef($_) } @results);
         }
 
-        my $result = $results[0];
-        if (ref($result) && eval { $result->can('can') }) {
-            return $self->__NEW__($result);
-        }
-
-        Sidef::Perl::Perl->to_sidef($result);
+        Sidef::Perl::Perl->to_sidef($results[0]);
     }
 }
 
