@@ -13,6 +13,16 @@ package Sidef::Sys::Sys {
         exit($code // 0);
     }
 
+    sub wait {
+        my ($self) = @_;
+        Sidef::Types::Number::Number->new(CORE::wait);
+    }
+
+    sub fork {
+        my ($self) = @_;
+        Sidef::Types::Number::Number->new(fork() // return);
+    }
+
     sub alarm {
         my ($self, $sec) = @_;
 
@@ -41,8 +51,6 @@ package Sidef::Sys::Sys {
         Sidef::Types::Bool::Bool->new(Time::HiRes::nanosleep($sec->get_value));
     }
 
-    *nanoSleep = \&nanosleep;
-
     sub usleep {
         my ($self, $sec) = @_;
 
@@ -55,8 +63,6 @@ package Sidef::Sys::Sys {
         Sidef::Types::String::String->new($^O);
     }
 
-    *osName = \&osname;
-
     sub user {
         my ($self) = @_;
         Sidef::Types::String::String->new(CORE::getlogin);
@@ -141,12 +147,8 @@ package Sidef::Sys::Sys {
         if (CORE::ref($fh) eq 'GLOB') {
             return Sidef::Types::Bool::Bool->new(print {$fh} @args);
         }
-        elsif (eval { $fh->can('print') || $fh->can('AUTOLOAD') }) {
-            return $fh->print(@args);
-        }
 
-        CORE::warn "[WARN] Sys.printh(): invalid object handle: `$fh'\n";
-        return;
+        $fh->print(@args);
     }
 
     sub println {
@@ -259,6 +261,8 @@ package Sidef::Sys::Sys {
         Storable::dclone($obj);
     }
 
+    *clone = \&copy;
+
     sub select {
         my ($self, $fh) = @_;
         CORE::select(CORE::ref($fh) eq 'GLOB' ? $fh : $fh->get_value);
