@@ -25,7 +25,7 @@ package Sidef::Types::Array::Array {
         foreach my $i (0 .. $#{$self}) {
             my $item = $self->[$i]->get_value;
 
-            if (ref($item) =~ /^Sidef::/) {
+            if (index(ref($item), 'Sidef::') == 0) {
                 push @array, $item->get_value;
             }
             else {
@@ -45,8 +45,11 @@ package Sidef::Types::Array::Array {
 
         my @array;
         if (defined $arg) {
-            foreach my $i (0 .. $#{$self}) {
-                push @array, $self->[$i]->get_value->$operator($arg->[$i]->get_value);
+            my $argc  = @{$arg};
+            my $selfc = @{$self};
+            my $max   = $argc > $selfc ? $argc - 1 : $selfc - 1;
+            foreach my $i (0 .. $max) {
+                push @array, $self->[$i % $selfc]->get_value->$operator($arg->[$i % $argc]->get_value);
             }
         }
         else {
@@ -175,8 +178,6 @@ package Sidef::Types::Array::Array {
         Sidef::Types::Bool::Bool->new($#{$self} == -1);
     }
 
-    *isEmpty = \&is_empty;
-
     sub subtract {
         my ($self, $array) = @_;
         $self->_grep($array, 1);
@@ -247,7 +248,7 @@ package Sidef::Types::Array::Array {
         my ($self, $obj) = @_;
 
         my $counter = 0;
-        if ($obj->can('run')) {
+        if ($obj->SUPER::isa('Sidef::Types::Block::Code')) {
 
             foreach my $item (@{$self}) {
                 if ($obj->run($item->get_value)) {
@@ -269,9 +270,6 @@ package Sidef::Types::Array::Array {
         Sidef::Types::Number::Number->new($counter);
     }
 
-    *countObj  = \&count;
-    *count_obj = \&count;
-
     sub equals {
         my ($self, $array) = @_;
 
@@ -361,7 +359,7 @@ package Sidef::Types::Array::Array {
         $_[0]->reduce_operator('+');
     }
 
-    *combine = \&sum;
+    *collapse = \&sum;
 
     sub prod {
         $_[0]->reduce_operator('*');
@@ -387,8 +385,6 @@ package Sidef::Types::Array::Array {
         $max;
     }
 
-    *maxBy = \&max_by;
-
     sub min_by {
         my ($self, $code) = @_;
 
@@ -407,8 +403,6 @@ package Sidef::Types::Array::Array {
         $min;
     }
 
-    *minBy = \&min_by;
-
     sub last {
         my ($self, $arg) = @_;
 
@@ -430,7 +424,7 @@ package Sidef::Types::Array::Array {
         my ($self, $arg) = @_;
 
         if (defined $arg) {
-            if ($arg->can('run')) {
+            if ($arg->SUPER::isa('Sidef::Types::Block::Code')) {
                 return return $self->find($arg);
             }
 
@@ -469,7 +463,7 @@ package Sidef::Types::Array::Array {
         Sidef::Types::Bool::Bool->new(exists $self->[$index->get_value]);
     }
 
-    *existsIndex = \&exists;
+    *has_index = \&exists;
 
     sub defined {
         my ($self, $index) = @_;
@@ -528,7 +522,6 @@ package Sidef::Types::Array::Array {
         $self->new(map { $_->get_value } _slice(@_));
     }
 
-    *fromTo  = \&ft;
     *from_to = \&ft;
 
     sub each {
@@ -577,6 +570,15 @@ package Sidef::Types::Array::Array {
 
     *collect = \&map;
 
+    sub flat_map {
+        my ($self, $code) = @_;
+        $self->new(
+            map {
+                map { $_->get_value } @{$code->run($_->get_value)}
+              } @{$self}
+        );
+    }
+
     sub grep {
         my ($self, $code) = @_;
         $self->new(grep { $code->run($_) } map { $_->get_value } @{$self});
@@ -598,8 +600,6 @@ package Sidef::Types::Array::Array {
         $hash;
     }
 
-    *groupBy = \&group_by;
-
     sub find {
         my ($self, $code) = @_;
         foreach my $var (@{$self}) {
@@ -640,19 +640,40 @@ package Sidef::Types::Array::Array {
     sub assign_to {
         my ($self, @vars) = @_;
 
-        for my $i (0 .. $#vars) {
+        my @values = splice(@{$self}, 0, $#vars + 1);
 
-            if (exists $self->[$i]) {
-                $vars[$i]->get_var->set_value($self->[$i]->get_value);
+        for my $i (0 .. $#vars) {
+            if (exists $values[$i]) {
+                $vars[$i]->get_var->set_value($values[$i]->get_value);
             }
         }
 
-        $self;
+        $self->new(@values);
     }
 
-    *unroll_to = \&assign_to;
-    *unrollTo  = \&assign_to;
-    *assignTo  = \&assign_to;
+    sub index {
+        my ($self, $obj) = @_;
+
+        state $method = '=';
+        foreach my $i (0 .. $#{$self}) {
+            $self->[$i]->get_value->$method($obj)
+              && return Sidef::Types::Number::Number->new($i);
+        }
+
+        Sidef::Types::Number::Number->new(-1);
+    }
+
+    sub rindex {
+        my ($self, $obj) = @_;
+
+        state $method = '=';
+        for (my $i = $#{$self} ; $i >= 0 ; $i--) {
+            $self->[$i]->get_value->$method($obj)
+              && return Sidef::Types::Number::Number->new($i);
+        }
+
+        Sidef::Types::Number::Number->new(-1);
+    }
 
     sub first_index {
         my ($self, $code) = @_;
@@ -665,9 +686,6 @@ package Sidef::Types::Array::Array {
         Sidef::Types::Number::Number->new(-1);
     }
 
-    *indexWhere = \&first_index;
-    *firstIndex = \&first_index;
-
     sub last_index {
         my ($self, $code) = @_;
 
@@ -679,9 +697,6 @@ package Sidef::Types::Array::Array {
         Sidef::Types::Number::Number->new(-1);
     }
 
-    *lastIndexWhere = \&last_index;
-    *lastIndex      = \&last_index;
-
     sub reduce_pairs {
         my ($self, $obj) = @_;
 
@@ -689,7 +704,7 @@ package Sidef::Types::Array::Array {
           && return $self->new;
 
         my @array;
-        if ($obj->can('run')) {
+        if ($obj->SUPER::isa('Sidef::Types::Block::Code')) {
             for (my $i = 1 ; $i <= $offset ; $i += 2) {
                 push @array, $obj->run($self->[$i - 1]->get_value, $self->[$i]->get_value);
             }
@@ -705,8 +720,6 @@ package Sidef::Types::Array::Array {
         $self->new(@array);
     }
 
-    *reducePairs = \&reduce_pairs;
-
     sub shuffle {
         my ($self) = @_;
         state $x = require List::Util;
@@ -733,8 +746,7 @@ package Sidef::Types::Array::Array {
         $t;
     }
 
-    *bshuffle    = \&best_shuffle;
-    *bestShuffle = \&best_shuffle;
+    *bshuffle = \&best_shuffle;
 
     sub pair_with {
         my ($self, @args) = @_;
@@ -746,7 +758,7 @@ package Sidef::Types::Array::Array {
     sub reduce {
         my ($self, $obj) = @_;
 
-        if ($obj->can('run')) {
+        if ($obj->SUPER::isa('Sidef::Types::Block::Code')) {
             (my $offset = $#{$self}) >= 0 || return;
 
             my $x = $self->[0]->get_value;
@@ -783,7 +795,6 @@ package Sidef::Types::Array::Array {
         $num;
     }
 
-    *resizeTo  = \&resize;
     *resize_to = \&resize;
 
     sub rand {
@@ -856,15 +867,13 @@ package Sidef::Types::Array::Array {
         $self->_unique(1);
     }
 
-    *last_uniq  = \&last_unique;
-    *lastUniq   = \&last_unique;
-    *lastUnique = \&last_unique;
+    *last_uniq = \&last_unique;
 
     sub abbrev {
         my ($self, $code) = @_;
 
-        my $__END__ = {};                                      # some unique value
-        my $__CALL__ = defined($code) && $code->can('call');
+        my $__END__ = {};                                                                  # some unique value
+        my $__CALL__ = defined($code) && $code->SUPER::isa('Sidef::Types::Block::Code');
 
         my %table;
         foreach my $sub_array (map { $_->get_value } @{$self}) {
@@ -921,7 +930,7 @@ package Sidef::Types::Array::Array {
     sub contains {
         my ($self, $obj) = @_;
 
-        if ($obj->can('run')) {
+        if ($obj->SUPER::isa('Sidef::Types::Block::Code')) {
             foreach my $item (@{$self}) {
                 if ($obj->run($item->get_value)) {
                     return Sidef::Types::Bool::Bool->true;
@@ -955,8 +964,6 @@ package Sidef::Types::Array::Array {
         return Sidef::Types::Bool::Bool->false;
     }
 
-    *containsType = \&contains_type;
-
     sub contains_any {
         my ($self, $array) = @_;
 
@@ -967,8 +974,6 @@ package Sidef::Types::Array::Array {
         Sidef::Types::Bool::Bool->false;
     }
 
-    *containsAny = \&contains_any;
-
     sub contains_all {
         my ($self, $array) = @_;
 
@@ -979,8 +984,6 @@ package Sidef::Types::Array::Array {
         Sidef::Types::Bool::Bool->true;
     }
 
-    *containsAll = \&contains_all;
-
     sub shift {
         my ($self, $num) = @_;
 
@@ -992,9 +995,7 @@ package Sidef::Types::Array::Array {
         shift(@{$self})->get_value;
     }
 
-    *dropFirst  = \&shift;
     *drop_first = \&shift;
-    *dropLeft   = \&shift;
     *drop_left  = \&shift;
 
     sub pop {
@@ -1010,9 +1011,7 @@ package Sidef::Types::Array::Array {
     }
 
     *drop_last  = \&pop;
-    *dropLast   = \&pop;
     *drop_right = \&pop;
-    *dropRight  = \&pop;
 
     sub pop_rand {
         my ($self) = @_;
@@ -1020,16 +1019,12 @@ package Sidef::Types::Array::Array {
         CORE::splice(@{$self}, CORE::rand($#{$self} + 1), 1)->get_value;
     }
 
-    *popRand = \&pop_rand;
-
     sub delete_index {
         my ($self, $offset) = @_;
         CORE::splice(@{$self}, $offset->get_value, 1)->get_value;
     }
 
-    *pop_at      = \&delete_index;
-    *deleteIndex = \&delete_index;
-    *popAt       = \&delete_index;
+    *pop_at = \&delete_index;
 
     sub splice {
         my ($self, $offset, $length, @objects) = @_;
@@ -1044,7 +1039,7 @@ package Sidef::Types::Array::Array {
         $self->new(map { $_->get_value } CORE::splice(@{$self}, $offset, $length));
     }
 
-    sub takeRight {
+    sub take_right {
         my ($self, $amount) = @_;
 
         my $offset = $#{$self};
@@ -1052,17 +1047,13 @@ package Sidef::Types::Array::Array {
         $self->new(map { $_->get_value } @{$self}[$offset - $amount .. $offset]);
     }
 
-    *take_right = \&takeRight;
-
-    sub takeLeft {
+    sub take_left {
         my ($self, $amount) = @_;
 
         $amount = $#{$self} > ($amount->get_value - 1) ? $amount->get_value - 1 : $#{$self};
         $self->new(map { $_->get_value } @{$self}[0 .. $amount]);
     }
 
-    *take_left = \&takeLeft;
-
     sub sort {
         my ($self, $code) = @_;
 
@@ -1190,17 +1181,15 @@ package Sidef::Types::Array::Array {
 
     sub copy {
         my ($self) = @_;
-        my $new = $self->new;
-        foreach my $item (map { $_->get_value } @{$self}) {
-            $new->append(eval { $item->can('copy') } ? $item->copy : $item);
-        }
-        $new;
+
+        state $x = require Storable;
+        Storable::dclone($self);
     }
 
     sub delete_first {
         my ($self, $obj) = @_;
 
-        my $method = '==';
+        state $method = '==';
         foreach my $i (0 .. $#{$self}) {
             my $var  = $self->[$i];
             my $item = $var->get_value;
@@ -1215,8 +1204,25 @@ package Sidef::Types::Array::Array {
     }
 
     *remove_first = \&delete_first;
-    *removeFirst  = \&delete_first;
-    *deleteFirst  = \&delete_first;
+
+    sub delete_last {
+        my ($self, $obj) = @_;
+
+        state $method = '==';
+        for (my $i = $#{$self} ; $i >= 0 ; $i--) {
+            my $var  = $self->[$i];
+            my $item = $var->get_value;
+            if (ref($item) eq ref($obj)
+                and $item->$method($obj)) {
+                CORE::splice(@{$self}, $i, 1);
+                return Sidef::Types::Bool::Bool->true;
+            }
+        }
+
+        Sidef::Types::Bool::Bool->false;
+    }
+
+    *remove_last = \&delete_first;
 
     sub delete {
         my ($self, $obj) = @_;
@@ -1246,8 +1252,6 @@ package Sidef::Types::Array::Array {
     }
 
     *remove_if = \&delete_if;
-    *removeIf  = \&delete_if;
-    *deleteIf  = \&delete_if;
 
     sub delete_first_if {
         my ($self, $code) = @_;
@@ -1264,8 +1268,6 @@ package Sidef::Types::Array::Array {
     }
 
     *remove_first_if = \&delete_first_if;
-    *removeFirstIf   = \&delete_first_if;
-    *deleteFirstIf   = \&delete_first_if;
 
     sub to_list {
         Sidef::Types::Array::List->new(map { $_->get_value } @{$_[0]});
@@ -1296,8 +1298,10 @@ package Sidef::Types::Array::Array {
 
         *{__PACKAGE__ . '::' . '&'}   = \&and;
         *{__PACKAGE__ . '::' . '*'}   = \&multiply;
-        *{__PACKAGE__ . '::' . '<<'}  = \&dropLeft;
-        *{__PACKAGE__ . '::' . '>>'}  = \&dropRight;
+        *{__PACKAGE__ . '::' . '<<'}  = \&append;
+        *{__PACKAGE__ . '::' . '«'}  = \&append;
+        *{__PACKAGE__ . '::' . '>>'}  = \&assign_to;
+        *{__PACKAGE__ . '::' . '»'}  = \&assign_to;
         *{__PACKAGE__ . '::' . '|'}   = \&or;
         *{__PACKAGE__ . '::' . '^'}   = \&xor;
         *{__PACKAGE__ . '::' . '+'}   = \&concat;
@@ -1306,8 +1310,6 @@ package Sidef::Types::Array::Array {
         *{__PACKAGE__ . '::' . '!='}  = \&ne;
         *{__PACKAGE__ . '::' . ':'}   = \&pair_with;
         *{__PACKAGE__ . '::' . '/'}   = \&divide;
-        *{__PACKAGE__ . '::' . '»'}  = \&assign_to;
-        *{__PACKAGE__ . '::' . '«'}  = \&append;
         *{__PACKAGE__ . '::' . '...'} = \&to_list;
 
         *{__PACKAGE__ . '::' . '++'} = sub {
