@@ -6,6 +6,10 @@ package Sidef::Types::Array::MultiArray {
       Sidef::Object::Object
       );
 
+    use overload
+      q{""}   => \&dump,
+      q{bool} => sub { scalar @{$_[0]} };
+
     sub new {
         my (undef, @args) = @_;
         my @array = map {
@@ -18,17 +22,25 @@ package Sidef::Types::Array::MultiArray {
         my ($self) = @_;
         [
          map {
-             [map { ref($_) =~ /^Sidef::/ ? $_->get_value : $_ } @{$_}]
+             [map { index(ref($_), 'Sidef::') == 0 ? $_->get_value : $_ } @{$_}]
            } @{$self}
         ];
     }
 
+    sub _max {
+        my ($self) = @_;
+        state $x = require List::Util;
+        List::Util::max(map { $#{$_} } @{$self});
+    }
+
     sub map {
         my ($self, $code) = @_;
 
+        my $max = $self->_max;
+
         my @arr;
-        foreach my $i (0 .. $#{$self->[0]}) {
-            push @arr, scalar $code->run(map { $_->[$i] } @{$self});
+        foreach my $i (0 .. $max) {
+            push @arr, scalar $code->run(map { $_->[$i % @{$_}] } @{$self});
         }
 
         Sidef::Types::Array::Array->new(@arr);
@@ -37,8 +49,10 @@ package Sidef::Types::Array::MultiArray {
     sub each {
         my ($self, $code) = @_;
 
-        foreach my $i (0 .. $#{$self->[0]}) {
-            if (defined(my $res = $code->_run_code(map { $_->[$i] } @{$self}))) {
+        my $max = $self->_max;
+
+        foreach my $i (0 .. $max) {
+            if (defined(my $res = $code->_run_code(map { $_->[$i % @{$_}] } @{$self}))) {
                 return $res;
             }
         }
