@@ -106,16 +106,13 @@ package Sidef::Types::Block::Code {
         Sidef::Types::Hash::Hash->new($self->_execute);
     }
 
-    *toHash = \&to_hash;
-    *to_h   = \&to_hash;
+    *to_h = \&to_hash;
 
     sub to_array {
         my ($self) = @_;
         Sidef::Types::Array::Array->new($self->_execute);
     }
 
-    *toArray = \&to_array;
-
     sub _run_code {
         my ($self, @args) = @_;
         my $result = $self->run(@args);
@@ -155,6 +152,32 @@ package Sidef::Types::Block::Code {
 
     *do = \&exec;
 
+    sub all {
+        my ($self) = @_;
+
+        foreach my $class (keys %{$self->{code}}) {
+            foreach my $statement (@{$self->{code}{$class}}) {
+                $exec->execute_expr(ref($statement) eq 'HASH' ? $statement : {self => $statement})
+                  || return Sidef::Types::Bool::Bool->false;
+            }
+        }
+
+        Sidef::Types::Bool::Bool->true;
+    }
+
+    sub any {
+        my ($self) = @_;
+
+        foreach my $class (keys %{$self->{code}}) {
+            foreach my $statement (@{$self->{code}{$class}}) {
+                $exec->execute_expr(ref($statement) eq 'HASH' ? $statement : {self => $statement})
+                  && return Sidef::Types::Bool::Bool->true;
+            }
+        }
+
+        Sidef::Types::Bool::Bool->false;
+    }
+
     sub while {
         my ($self, $condition, $old_self) = @_;
 
