@@ -18,8 +18,8 @@ package Sidef::Types::Hash::Hash {
 
         if (@pairs == 1) {
 
-            # Block to hash
-            if (ref($pairs[0]) eq 'Sidef::Types::Block::Code') {
+            # Any object to hash
+            if ($pairs[0]->can('to_hash')) {
                 return $pairs[0]->to_hash;
             }
         }
@@ -51,7 +51,7 @@ package Sidef::Types::Hash::Hash {
         while (my ($k, $v) = each %{$self->{data}}) {
             my $rv = $v->get_value;
             $hash{$k} = (
-                         ref($rv) =~ /^Sidef::/
+                         index(ref($rv), 'Sidef::') == 0
                          ? $rv->get_value
                          : $rv
                         );
@@ -103,8 +103,6 @@ package Sidef::Types::Hash::Hash {
         Sidef::Types::Bool::Bool->true;
     }
 
-    *duplicateOf = \&duplicate_of;
-
     sub eq {
         my ($self, $obj) = @_;
 
@@ -136,11 +134,10 @@ package Sidef::Types::Hash::Hash {
     *add = \&append;
 
     sub delete {
-        my ($self, $key) = @_;
-        if (exists $self->{data}{$key}) {
-            return (delete $self->{data}{$key})->get_value;
-        }
-        return;
+        my ($self, @keys) = @_;
+        @keys == 1
+          ? delete($self->{data}{$keys[0]})
+          : Sidef::Types::Array::List->new(delete @{$self->{data}}{@keys});
     }
 
     sub _iterate {
@@ -158,7 +155,7 @@ package Sidef::Types::Hash::Hash {
         $self;
     }
 
-    sub mapval {
+    sub map_val {
         my ($self, $code) = @_;
 
         while (my ($key, $value) = each %{$self->{data}}) {
@@ -173,21 +170,18 @@ package Sidef::Types::Hash::Hash {
         $self;
     }
 
-    *mapVal  = \&mapval;
-    *map_val = \&mapval;
-
     sub select {
         my ($self, $code) = @_;
 
-        my $new_hash = $self->new;
+        my @pairs;
         $self->_iterate(
             $code,
             sub {
-                $new_hash->append(@_);
+                push @pairs, @_;
             }
         );
 
-        $new_hash;
+        $self->new(@pairs);
     }
 
     *grep = \&select;
@@ -233,8 +227,6 @@ package Sidef::Types::Hash::Hash {
         $self;
     }
 
-    *mergeValues = \&merge_values;
-
     sub keys {
         my ($self) = @_;
         Sidef::Types::Array::Array->new(map { Sidef::Types::String::String->new($_) } keys %{$self->{data}});
@@ -327,21 +319,24 @@ package Sidef::Types::Hash::Hash {
     }
 
     *has_key  = \&exists;
-    *haskey   = \&exists;
     *contains = \&exists;
 
     sub flip {
         my ($self) = @_;
 
         my $new_hash = $self->new();
-        @{$new_hash}{CORE::values %{$self->{data}}} =
-          (map { Sidef::Types::String::String->new($_) } CORE::keys %{$self->{data}});
+        @{$new_hash->{data}}{map { $_->get_value } CORE::values %{$self->{data}}} =
+          (map { Sidef::Variable::Variable->new(name => '', type => 'var', value => Sidef::Types::String::String->new($_)) }
+            CORE::keys %{$self->{data}});
+
         $new_hash;
     }
 
     sub copy {
         my ($self) = @_;
-        $self->new(map { ref($_) ? $_->get_value : $_ } %{$self->{data}});
+
+        state $x = require Storable;
+        Storable::dclone($self);
     }
 
     sub dump {
@@ -384,7 +379,7 @@ package Sidef::Types::Hash::Hash {
         no strict 'refs';
 
         *{__PACKAGE__ . '::' . '+'}   = \&concat;
-        *{__PACKAGE__ . '::' . '==='} = \&duplicateOf;
+        *{__PACKAGE__ . '::' . '==='} = \&duplicate_of;
         *{__PACKAGE__ . '::' . '=='}  = \&eq;
         *{__PACKAGE__ . '::' . '!='}  = \&ne;
         *{__PACKAGE__ . '::' . ':'}   = \&new;
