@@ -8,6 +8,10 @@ package Sidef::Types::Number::Complex {
       Sidef::Types::Number::Number
       );
 
+    use overload
+      q{""}   => \&get_value,
+      q{bool} => \&get_value;
+
     sub new {
         my (undef, $x, $y) = @_;
 
@@ -94,7 +98,6 @@ package Sidef::Types::Number::Complex {
     }
 
     *re = \&real;
-    *Re = \&real;
 
     sub imaginary {
         my ($self) = @_;
@@ -103,7 +106,6 @@ package Sidef::Types::Number::Complex {
     }
 
     *im = \&imaginary;
-    *Im = \&imaginary;
 
     sub reciprocal {
         __PACKAGE__->new(1)->div($_[0]);
@@ -183,14 +185,11 @@ package Sidef::Types::Number::Complex {
         Sidef::Types::Bool::Bool->new($self->get_value == 0);
     }
 
-    *isZero = \&is_zero;
-
     sub is_nan {
         my ($self) = @_;
         Sidef::Types::Bool::Bool->false;
     }
 
-    *isNaN  = \&is_nan;
     *is_NaN = \&is_nan;
 
     sub is_positive {
@@ -198,50 +197,38 @@ package Sidef::Types::Number::Complex {
         Sidef::Types::Bool::Bool->new($self->get_value >= 0);
     }
 
-    *isPositive = \&is_positive;
-    *isPos      = \&is_positive;
-    *is_pos     = \&is_positive;
+    *is_pos = \&is_positive;
 
     sub is_negative {
         my ($self) = @_;
         Sidef::Types::Bool::Bool->new($self->get_value < 0);
     }
 
-    *isNegative = \&is_negative;
-    *isNeg      = \&is_negative;
-    *is_neg     = \&is_negative;
+    *is_neg = \&is_negative;
 
     sub is_even {
         my ($self) = @_;
         Sidef::Types::Bool::Bool->new($self->get_value % 2 == 0);
     }
 
-    *isEven = \&is_even;
-
     sub is_odd {
         my ($self) = @_;
         Sidef::Types::Bool::Bool->new($self->get_value % 2 != 0);
     }
 
-    *isOdd = \&is_odd;
-
     sub is_inf {
         my ($self) = @_;
         Sidef::Types::Bool::Bool->new($self->get_value == 'inf');
     }
 
-    *isInf       = \&is_inf;
     *is_infinite = \&is_inf;
-    *isInfinite  = \&is_inf;
 
     sub is_integer {
         my ($self) = @_;
         Sidef::Types::Bool::Bool->new($self->get_value == CORE::int($self->get_value));
     }
 
-    *isInt     = \&is_integer;
-    *is_int    = \&is_integer;
-    *isInteger = \&is_integer;
+    *is_int = \&is_integer;
 
     sub rand {
         my ($self, $max) = @_;
@@ -274,7 +261,6 @@ package Sidef::Types::Number::Complex {
     }
 
     *fround = \&roundf;
-    *fRound = \&roundf;
 
     sub digit { ... }
 
