@@ -34,8 +34,7 @@ package Sidef::Types::String::String {
         $_[0];
     }
 
-    *to_str    = \&to_s;
-    *to_string = \&to_s;
+    *to_str = \&to_s;
 
     sub unroll_operator {
         my ($self, $operator, $arg) = @_;
@@ -131,8 +130,6 @@ package Sidef::Types::String::String {
         }
     }
 
-    *matches = \&match;
-
     {
         my %cache;
 
@@ -148,8 +145,6 @@ package Sidef::Types::String::String {
         }
     }
 
-    *gmatches = \&gmatch;
-
     sub array_to {
         my ($self, $string) = @_;
 
@@ -179,8 +174,8 @@ package Sidef::Types::String::String {
                                              );
     }
 
+    *up_to = \&to;
     *upto  = \&to;
-    *upTo  = \&to;
     *range = \&to;
 
     sub downto {
@@ -192,7 +187,7 @@ package Sidef::Types::String::String {
                                              );
     }
 
-    *downTo = \&downto;
+    *down_to = \&downto;
 
     sub cmp {
         my ($self, $string) = @_;
@@ -237,10 +232,8 @@ package Sidef::Types::String::String {
         $self->new(CORE::uc $self->get_value);
     }
 
-    *toUpperCase = \&uc;
-    *upcase      = \&uc;
-    *upCase      = \&uc;
-    *upper       = \&uc;
+    *upcase = \&uc;
+    *upper  = \&uc;
 
     sub equals {
         my ($self, $arg) = @_;
@@ -269,31 +262,28 @@ package Sidef::Types::String::String {
         $self->new(CORE::ucfirst $self->get_value);
     }
 
-    *tc         = \&ucfirst;
-    *titleCase  = \&ucfirst;
-    *title_case = \&ucfirst;
+    *tc        = \&ucfirst;
+    *titlecase = \&ucfirst;
 
     sub lc {
         my ($self) = @_;
         $self->new(CORE::lc $self->get_value);
     }
 
-    *toLowerCase = \&lc;
-    *downcase    = \&lc;
-    *downCase    = \&lc;
-    *lower       = \&lc;
+    *downcase = \&lc;
+    *lower    = \&lc;
 
     sub lcfirst {
         my ($self) = @_;
         $self->new(CORE::lcfirst $self->get_value);
     }
 
-    sub charAt {
+    sub char {
         my ($self, $pos) = @_;
         Sidef::Types::Char::Char->new(CORE::substr($self->get_value, $pos->get_value, 1));
     }
 
-    *char_at = \&charAt;
+    *char_at = \&char;
 
     sub wordcase {
         my ($self) = @_;
@@ -312,8 +302,7 @@ package Sidef::Types::String::String {
         $self->new($string);
     }
 
-    *wc       = \&wordcase;
-    *wordCase = \&wordcase;
+    *wc = \&wordcase;
 
     sub capitalize {
         my ($self) = @_;
@@ -352,6 +341,24 @@ package Sidef::Types::String::String {
         Sidef::Types::Number::Number->new(CORE::hex($self->get_value));
     }
 
+    sub oct {
+        my ($self) = @_;
+        Sidef::Types::Number::Number->new(CORE::oct($self->get_value));
+    }
+
+    sub bin {
+        my ($self) = @_;
+        my $value = $self->get_value;
+        Sidef::Types::Number::Number->new(CORE::oct(index($value, '0b') == 0 ? $value : ('0b' . $value)));
+    }
+
+    sub num {
+        my ($self) = @_;
+        Sidef::Types::Number::Number->new($self->get_value);
+    }
+
+    *dec = \&num;
+
     sub substr {
         my ($self, $offs, $len) = @_;
         __PACKAGE__->new(
@@ -386,8 +393,6 @@ package Sidef::Types::String::String {
         Sidef::Types::Bool::Bool->new($self->get_value eq '');
     }
 
-    *isEmpty = \&is_empty;
-
     sub index {
         my ($self, $substr, $pos) = @_;
         Sidef::Types::Number::Number->new(
@@ -397,8 +402,6 @@ package Sidef::Types::String::String {
                                          );
     }
 
-    *indexOf = \&index;
-
     sub ord {
         my ($self) = @_;
         Sidef::Types::Number::Number->new(CORE::ord($self->get_value));
@@ -447,11 +450,11 @@ package Sidef::Types::String::String {
     sub sub {
         my ($self, $regex, $str) = @_;
 
-        ref($str) eq 'Sidef::Types::Block::Code'
-          && return $self->esub($regex, $str);
-
         $str //= __PACKAGE__->new('');
 
+        $str->SUPER::isa('Sidef::Types::Block::Code')
+          && return $self->esub($regex, $str);
+
         if (ref($regex) eq 'Sidef::Types::Regex::Regex') {
             $regex->match($self)->{matched} or return $self;
         }
@@ -467,11 +470,11 @@ package Sidef::Types::String::String {
     sub gsub {
         my ($self, $regex, $str) = @_;
 
-        ref($str) eq 'Sidef::Types::Block::Code'
-          && return $self->gesub($regex, $str);
-
         $str //= __PACKAGE__->new('');
 
+        $str->SUPER::isa('Sidef::Types::Block::Code')
+          && return $self->gesub($regex, $str);
+
         if (ref($regex) eq 'Sidef::Types::Regex::Regex') {
             $regex->match($self)->{matched} or return $self;
         }
@@ -481,8 +484,6 @@ package Sidef::Types::String::String {
         $self->new($self->get_value =~ s{$search}{$value}gr);
     }
 
-    *gReplace = \&gsub;
-
     sub _get_captures {
         my ($string) = @_;
         map { __PACKAGE__->new(CORE::substr($string, $-[$_], $+[$_] - $-[$_])) } 1 .. $#{-};
@@ -498,7 +499,7 @@ package Sidef::Types::String::String {
             $regex->match($self)->{matched} or return $self;
         }
 
-        if (ref($code) eq 'Sidef::Types::Block::Code') {
+        if ($code->SUPER::isa('Sidef::Types::Block::Code')) {
             return __PACKAGE__->new($self->get_value =~ s{$search}{$code->run(_get_captures($self->get_value))}er);
         }
 
@@ -515,7 +516,7 @@ package Sidef::Types::String::String {
             $regex->match($self)->{matched} or return $self;
         }
 
-        if (ref($code) eq 'Sidef::Types::Block::Code') {
+        if ($code->SUPER::isa('Sidef::Types::Block::Code')) {
             my $value = $self->get_value;
             return __PACKAGE__->new($value =~ s{$search}{$code->run(_get_captures($value))}ger);
         }
@@ -597,8 +598,7 @@ package Sidef::Types::String::String {
         $array->each($obj);
     }
 
-    *words    = \&each_word;
-    *eachWord = \&each_word;
+    *words = \&each_word;
 
     sub bytes {
         my ($self) = @_;
@@ -623,7 +623,6 @@ package Sidef::Types::String::String {
     }
 
     *each_char = \&each;
-    *eachChar  = \&each;
 
     sub lines {
         my ($self) = @_;
@@ -635,8 +634,6 @@ package Sidef::Types::String::String {
         $self->lines->each($obj);
     }
 
-    *eachLine = \&each_line;
-
     sub open_r {
         my ($self, @rest) = @_;
         state $x = require Encode;
@@ -664,8 +661,6 @@ package Sidef::Types::String::String {
     }
 
     *trim_beg = \&strip_beg;
-    *trimBeg  = \&strip_beg;
-    *stripBeg = \&strip_beg;
 
     sub strip_end {
         my ($self) = @_;
@@ -673,8 +668,6 @@ package Sidef::Types::String::String {
     }
 
     *trim_end = \&strip_end;
-    *trimEnd  = \&strip_end;
-    *stripEnd = \&strip_end;
 
     sub trans {
         my ($self, $orig, $repl) = @_;
@@ -736,8 +729,7 @@ package Sidef::Types::String::String {
         Sidef::Types::Array::Array->new(map { __PACKAGE__->new($_) } $str =~ /\X/g);
     }
 
-    *graphemes    = \&graphs;
-    *to_graphemes = \&graphs;
+    *graphemes = \&graphs;
 
     sub levenshtein {
         my ($self, $arg) = @_;
@@ -812,8 +804,6 @@ package Sidef::Types::String::String {
     }
 
     *starts_with = \&begins_with;
-    *startsWith  = \&begins_with;
-    *beginsWith  = \&begins_with;
 
     sub ends_with {
         my ($self, $string) = @_;
@@ -827,8 +817,6 @@ package Sidef::Types::String::String {
         Sidef::Types::Bool::Bool->false;
     }
 
-    *endsWith = \&ends_with;
-
     sub looks_like_number {
         my ($self) = @_;
         state $x = require Scalar::Util;
@@ -994,7 +982,7 @@ package Sidef::Types::String::String {
                     if (exists $chars[$i + 2] and $chars[$i + 2] eq '{') {
                         my $str = CORE::join('', @chars[$i + 2 .. $#chars]);
                         if ($str =~ /^\{(.*?)\}/) {
-                            splice(@chars, $i--, 2 + $+[0], chr(oct($1)));
+                            splice(@chars, $i--, 2 + $+[0], CORE::chr(CORE::oct($1)));
                             next;
                         }
                         else {
@@ -1009,7 +997,7 @@ package Sidef::Types::String::String {
                 elsif ($char =~ /^[0-7]/) {
                     my $str = CORE::join('', @chars[$i + 1 .. $#chars]);
                     if ($str =~ /^(0[0-7]{1,2}|[0-7]{1,2})/) {
-                        splice @chars, $i, 1 + $+[0], chr(oct($1));
+                        splice @chars, $i, 1 + $+[0], CORE::chr(CORE::oct($1));
                     }
                 }
                 elsif ($char eq 'd') {
@@ -1114,8 +1102,6 @@ package Sidef::Types::String::String {
         $self->new(Encode::decode_utf8(Encode::encode_utf8(CORE::join('', @chars))));
     }
 
-    *applyEscapes = \&apply_escapes;
-
     sub shift_left {
         my ($self, $i) = @_;
         my $len = CORE::length($self->get_value);
@@ -1123,25 +1109,19 @@ package Sidef::Types::String::String {
         $self->new(CORE::substr($self->get_value, $i));
     }
 
-    *dropLeft  = \&shift_left;
     *drop_left = \&shift_left;
-    *shiftLeft = \&shift_left;
 
     sub shift_right {
         my ($self, $i) = @_;
         $self->new(CORE::substr($self->get_value, 0, -$i->get_value));
     }
 
-    *dropRight  = \&shift_right;
     *drop_right = \&shift_right;
-    *shiftRight = \&shift_right;
 
     sub pair_with {
         Sidef::Types::Array::Pair->new($_[0], $_[1]);
     }
 
-    *pairWith = \&pair_with;
-
     sub basic_dump {
         my ($self) = @_;
         __PACKAGE__->new(q{'} . $self->get_value =~ s{([\\'])}{\\$1}gr . q{'});
